==> monaco-vscode-api-4.1.0.tgz: package/vscode/src/vs/workbench/contrib/terminal/common/terminalClipboard.js <==
import { localizeWithPath } from '../../../../nls.js';
import { IConfigurationService } from '../../../../platform/configuration/common/configuration.js';
import '../../../../../../../override/vs/platform/dialogs/common/dialogs.js';
import { IDialogService } from '../../../../platform/dialogs/common/dialogs.js';
async function shouldPasteTerminalText(accessor, text, bracketedPasteMode) {
    const configurationService = accessor.get(IConfigurationService);
    const dialogService = accessor.get(IDialogService);
    const textForLines = text.split(/\r?\n/);
    if (textForLines.length === 1) {
        return true;
    }
    function parseConfigValue(value) {
        if (typeof value === 'string') {
            if (value === 'auto' || value === 'always' || value === 'never') {
                return value;
            }
        }
        if (typeof value === 'boolean') {
            return value ? 'auto' : 'never';
        }
        return 'auto';
    }
    const configValue = parseConfigValue(configurationService.getValue("terminal.integrated.enableMultiLinePasteWarning" ));
    if (configValue === 'never') {
        return true;
    }
    if (configValue === 'auto') {
        if (bracketedPasteMode) {
            return true;
        }
        const textForLines = text.split(/\r?\n/);
        if (textForLines.length === 2 && textForLines[1].trim().length === 0) {
            return true;
        }
    }
    const displayItemsCount = 3;
    const maxPreviewLineLength = 30;
    let detail = ( localizeWithPath(
        'vs/workbench/contrib/terminal/common/terminalClipboard',
        'preview',
        "Preview:"
    ));
    for (let i = 0; i < Math.min(textForLines.length, displayItemsCount); i++) {
        const line = textForLines[i];
        const cleanedLine = line.length > maxPreviewLineLength ? `${line.slice(0, maxPreviewLineLength)}…` : line;
        detail += `\n${cleanedLine}`;
    }
    if (textForLines.length > displayItemsCount) {
        detail += `\n…`;
    }
    const { result, checkboxChecked } = await dialogService.prompt({
        message: ( localizeWithPath(
            'vs/workbench/contrib/terminal/common/terminalClipboard',
            'confirmMoveTrashMessageFilesAndDirectories',
            "Are you sure you want to paste {0} lines of text into the terminal?",
            textForLines.length
        )),
        detail,
        type: 'warning',
        buttons: [
            {
                label: ( localizeWithPath(
                    'vs/workbench/contrib/terminal/common/terminalClipboard',
                    { key: 'multiLinePasteButton', comment: ['&& denotes a mnemonic'] },
                    "&&Paste"
                )),
                run: () => ({ confirmed: true, singleLine: false })
            },
            {
                label: ( localizeWithPath(
                    'vs/workbench/contrib/terminal/common/terminalClipboard',
                    { key: 'multiLinePasteButton.oneLine', comment: ['&& denotes a mnemonic'] },
                    "Paste as &&one line"
                )),
                run: () => ({ confirmed: true, singleLine: true })
            }
        ],
        cancelButton: true,
        checkbox: {
            label: ( localizeWithPath(
                'vs/workbench/contrib/terminal/common/terminalClipboard',
                'doNotAskAgain',
                "Do not ask me again"
            ))
        }
    });
    if (!result) {
        return false;
    }
    if (result.confirmed && checkboxChecked) {
        await configurationService.updateValue("terminal.integrated.enableMultiLinePasteWarning" , false);
    }
    if (result.singleLine) {
        return { modifiedText: text.replace(/\r?\n/g, '') };
    }
    return result.confirmed;
}
export { shouldPasteTerminalText };

==> monaco-vscode-api-10.1.0.tgz: package/vscode/src/vs/workbench/contrib/terminal/common/terminalClipboard.js <==
import { localize } from '../../../../nls.js';
import { IConfigurationService } from '../../../../platform/configuration/common/configuration.service.js';
import { IDialogService } from '../../../../platform/dialogs/common/dialogs.service.js';
async function shouldPasteTerminalText(accessor, text, bracketedPasteMode) {
    const configurationService = accessor.get(IConfigurationService);
    const dialogService = accessor.get(IDialogService);
    const textForLines = text.split(/\r?\n/);
    if (textForLines.length === 1) {
        return true;
    }
    function parseConfigValue(value) {
        if (typeof value === 'string') {
            if (value === 'auto' || value === 'always' || value === 'never') {
                return value;
            }
        }
        if (typeof value === 'boolean') {
            return value ? 'auto' : 'never';
        }
        return 'auto';
    }
    const configValue = parseConfigValue(configurationService.getValue("terminal.integrated.enableMultiLinePasteWarning" ));
    if (configValue === 'never') {
        return true;
    }
    if (configValue === 'auto') {
        if (bracketedPasteMode) {
            return true;
        }
        const textForLines = text.split(/\r?\n/);
        if (textForLines.length === 2 && textForLines[1].trim().length === 0) {
            return true;
        }
    }
    const displayItemsCount = 3;
    const maxPreviewLineLength = 30;
    let detail = ( localize(11156, "Preview:"));
    for (let i = 0; i < Math.min(textForLines.length, displayItemsCount); i++) {
        const line = textForLines[i];
        const cleanedLine = line.length > maxPreviewLineLength ? `${line.slice(0, maxPreviewLineLength)}…` : line;
        detail += `\n${cleanedLine}`;
    }
    if (textForLines.length > displayItemsCount) {
        detail += `\n…`;
    }
    const { result, checkboxChecked } = await dialogService.prompt({
        message: ( localize(
            11157,
            "Are you sure you want to paste {0} lines of text into the terminal?",
            textForLines.length
        )),
        detail,
        type: 'warning',
        buttons: [
            {
                label: ( localize(11158, "&&Paste")),
                run: () => ({ confirmed: true, singleLine: false })
            },
            {
                label: ( localize(11159, "Paste as &&one line")),
                run: () => ({ confirmed: true, singleLine: true })
            }
        ],
        cancelButton: true,
        checkbox: {
            label: ( localize(11160, "Do not ask me again"))
        }
    });
    if (!result) {
        return false;
    }
    if (result.confirmed && checkboxChecked) {
        await configurationService.updateValue("terminal.integrated.enableMultiLinePasteWarning" , false);
    }
    if (result.singleLine) {
        return { modifiedText: text.replace(/\r?\n/g, '') };
    }
    return result.confirmed;
}
export { shouldPasteTerminalText };
